@@ -60,6 +60,7 @@ from tendenci.apps.events.models import Event, Registrant
 from tendenci.apps.base.utils import truncate_words
 from tendenci.apps.perms.utils import has_perm
 from tendenci.apps.files.models import File
+from tendenci.apps.files.validators import FileValidator
 from tendenci.apps.user_groups.models import Group
 
 
@@ -201,6 +202,8 @@ class CorpProfile(TendenciBaseModel):
                                blank=True, default='')
     phone = models.CharField(_('Phone'), max_length=50,
                              blank=True, default='')
+    phone2 = models.CharField(_('phone2'), max_length=50,
+                              blank=True, default='')
     email = models.CharField(_('Email'), max_length=200,
                              blank=True, default='')
     url = models.CharField(_('URL'), max_length=100, blank=True,
@@ -440,6 +443,7 @@ class CorpMembership(TendenciBaseModel):
                                        on_delete=models.SET_NULL)
 
     invoice = models.ForeignKey(Invoice, blank=True, null=True, on_delete=models.SET_NULL)
+    donation_amount = models.DecimalField(max_digits=15, decimal_places=2, blank=True, default=0)
 
     anonymous_creator = models.ForeignKey('Creator', null=True, on_delete=models.SET_NULL)
     admin_notes = models.TextField(_('Admin notes'),
@@ -773,7 +777,7 @@ class CorpMembership(TendenciBaseModel):
     def copy(self):
         corp_membership = self.__class__()
         field_names = [field.name for field in self.__class__._meta.fields]
-        ignore_fields = ['id', 'renewal', 'renew_dt', 'status',
+        ignore_fields = ['id', 'renewal', 'renew_dt', 'status', 'donation_amount',
                          'status_detail', 'approved', 'approved_denied_dt',
                          'approved_denied_user', 'anonymous_creator']
         for field in ignore_fields:
@@ -1158,9 +1162,10 @@ class CorpMembership(TendenciBaseModel):
         return False
 
     def allow_edit_by(self, this_user):
-        if self.is_active or self.is_expired:
-            if this_user.profile.is_superuser:
+        if this_user.profile.is_superuser:
                 return True
+
+        if self.is_active or self.is_expired:
             if has_perm(this_user, 'corporate_memberships.change_corpmembership'):
                 return True
 
@@ -1442,6 +1447,11 @@ class CorpMembershipApp(TendenciBaseModel):
     tax_rate = models.DecimalField(blank=True, max_digits=5, decimal_places=4, default=0,
                                    help_text=_('Example: 0.0825 for 8.25%.'))
 
+    donation_enabled = models.BooleanField(_("Enable Donation on Renewal"), default=False)
+    donation_label = models.CharField(_("Label"), max_length=255, blank=True, null=True)
+    donation_default_amount = models.DecimalField(_("Default Amount"), max_digits=15,
+                                                  decimal_places=2, blank=True, default=0)
+
     dues_reps_group = models.ForeignKey(Group, null=True,
         related_name='dues_reps_group',
         on_delete=models.SET_NULL,
@@ -1664,7 +1674,12 @@ class CorpMembershipAppField(OrderingBaseModel):
                             'corporate_membership_type',
                             'payment_method']:
                     if self.choices == 'yesno':
-                        field_args["choices"] = ((1, _('Yes')), (0, _('No')),)
+                        field_args["choices"] = ((True, _('Yes')), (False, _('No')),)
+                        if self.default_value:
+                            if self.default_value.lower() == 'yes':
+                                field_args['initial'] = True
+                            elif self.default_value.lower() == 'no':
+                                field_args['initial'] = False
                     else:
                         choices = self.choices.split(",")
                         field_args["choices"] = list(zip(choices, choices))
@@ -1674,6 +1689,8 @@ class CorpMembershipAppField(OrderingBaseModel):
                 if module == 'django.forms.extras':
                     module = 'django.forms.widgets'
                 field_args["widget"] = getattr(import_module(module), widget)
+            if self.field_type == 'FileField':
+                field_args["validators"] = [FileValidator()]
 
             return field_class(**field_args)
         return None
@@ -1963,11 +1980,11 @@ class Notice(models.Model):
     creator = models.ForeignKey(
         User, related_name="corporate_membership_notice_creator",
         null=True, on_delete=models.SET_NULL)
-    creator_username = models.CharField(max_length=50, null=True)
+    creator_username = models.CharField(max_length=150, null=True)
     owner = models.ForeignKey(
         User, related_name="corporate_membership_notice_owner",
         null=True, on_delete=models.SET_NULL)
-    owner_username = models.CharField(max_length=50, null=True)
+    owner_username = models.CharField(max_length=150, null=True)
     status_detail = models.CharField(choices=STATUS_DETAIL_CHOICES,
                                      default=STATUS_DETAIL_ACTIVE, max_length=50)
     status = models.BooleanField(default=True)
@@ -2033,6 +2050,15 @@ class Notice(models.Model):
                                      corporate_membership.invoice.get_absolute_url())
         else:
             invoice_link = ''
+            
+        if corporate_membership.corp_profile.directory:
+            directory_url = '{0}{1}'.format(site_url, reverse('directory',
+                                    args=[corporate_membership.corp_profile.directory.slug]))
+            directory_edit_url = '{0}{1}'.format(site_url, reverse('directory.edit',
+                                    args=[corporate_membership.corp_profile.directory.id]))
+        else:
+            directory_url = ''
+            directory_edit_url = ''
 
         corp_app = CorpMembershipApp.objects.current_app()
         authentication_info = render_to_string(
@@ -2053,6 +2079,8 @@ class Notice(models.Model):
             'renew_link': "%s%s" % (site_url,
                                     corporate_membership.get_renewal_url()),
             'invoice_link': invoice_link,
+            'directory_url': directory_url,
+            'directory_edit_url': directory_edit_url,
             'individuals_join_url': '%s%s' % (site_url,
                                 reverse('membership_default.corp_pre_add',
                                         args=[corporate_membership.id])),
@@ -2164,7 +2192,7 @@ class Notice(models.Model):
                                     recipient=recipient,
                                     anonymous_join_login_info=anonymous_join_login_info),
                         'corporate_membership_total': CorpMembership.objects.count(),
-                        'sender': notice.sender,
+                        'sender': get_setting('site', 'global', 'siteemailnoreplyaddress'),
                         'sender_display': notice.sender_display,
                     }
                     if notice.sender:
