@@ -5,10 +5,11 @@ from decimal import Decimal
 from django.utils.translation import ugettext_lazy as _
 from django import forms
 from django.contrib.contenttypes.models import ContentType
+from django.forms.utils import ErrorList
 
-from tendenci.core.perms.forms import TendenciBaseForm
+from tendenci.apps.perms.forms import TendenciBaseForm
 from tendenci.apps.discounts.models import Discount
-from tendenci.core.base.fields import SplitDateTimeField, PriceField
+from tendenci.apps.base.fields import PriceField
 from tendenci.apps.discounts.utils import assign_discount
 
 END_DT_INITIAL = datetime.now() + timedelta(weeks=4)
@@ -59,20 +60,21 @@ class DiscountForm(TendenciBaseForm):
                     })
                     ]
 
-    start_dt = SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
-    end_dt = SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
+    start_dt = forms.SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
+    end_dt = forms.SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
     status_detail = forms.ChoiceField(
         choices=(('active',_('Active')),('inactive',_('Inactive')), ('pending',_('Pending')),))
 
     def __init__(self, *args, **kwargs):
         super(DiscountForm, self).__init__(*args, **kwargs)
-        if not self.user.profile.is_superuser:
+        if self.user and not self.user.profile.is_superuser:
             if 'status_detail' in self.fields: self.fields.pop('status_detail')
 
         MODELS_WITH_DISCOUNT = ['registrationconfiguration',
                                 'membershipset']
         content_types = ContentType.objects.filter(model__in=MODELS_WITH_DISCOUNT)
-        self.fields['apps'].choices = ((c.id, c.app_label) for c in content_types)
+        if 'apps' in self.fields:
+            self.fields['apps'].choices = ((c.id, c.app_label) for c in content_types)
 
     def clean_discount_code(self):
         data = self.cleaned_data['discount_code']
@@ -137,6 +139,9 @@ class DiscountHandlingForm(forms.Form):
     def clean(self):
         code = self.cleaned_data.get('code', '')
         model = self.cleaned_data.get('model', '')
+        null_byte = chr(0)
+        if null_byte in code or null_byte in model:
+            raise forms.ValidationError(_('Not a valid discount code.'))
         [self.discount] = Discount.objects.filter(discount_code=code, apps__model=model)[:1] or [None]
         if not self.discount:
             raise forms.ValidationError(_('This is not a valid discount code.'))
