@@ -4,14 +4,16 @@ from django.utils.translation import ugettext_lazy as _
 from tendenci.apps.perms.admin import TendenciBaseModelAdmin
 from tendenci.apps.regions.models import Region
 from tendenci.apps.regions.forms import RegionForm
+from tendenci.apps.theme.templatetags.static import static
 
 
 class RegionAdmin(TendenciBaseModelAdmin):
     list_display = ['region_name', 'region_code',
                     'owner_link', 'admin_perms',
-                    'admin_status']
+                    'admin_status', 'position']
     list_filter = ['status_detail', 'owner_username']
     search_fields = ['region_name', 'region_code']
+    list_editable = ['position']
     fieldsets = (
         (_('Region Information'), {
             'fields': ('region_name',
@@ -30,6 +32,16 @@ class RegionAdmin(TendenciBaseModelAdmin):
             )}),
         )
     form = RegionForm
-    ordering = ['-update_dt']
+
+    class Media:
+        css = {
+            "all": (static("css/websymbols.css"),)
+        }
+        js = (
+            '//ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js',
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js',
+            static('js/admin/admin-list-reorder.js'),
+            static('js/global/tinymce.event_handlers.js'),
+        )
 
 admin.site.register(Region, RegionAdmin)
