@@ -1,12 +1,13 @@
 import operator
 from haystack.query import SearchQuerySet
+from functools import reduce
 
 from django.db.models import Manager
 from django.db.models import Q
 from django.contrib.auth.models import User, AnonymousUser
 
-from tendenci.core.perms.managers import TendenciBaseManager
-from tendenci.core.site_settings.utils import get_global_setting
+from tendenci.apps.perms.managers import TendenciBaseManager
+from tendenci.apps.site_settings.utils import get_global_setting
 
 
 class GroupManager(TendenciBaseManager):
@@ -22,13 +23,14 @@ class GroupManager(TendenciBaseManager):
 
     def get_or_create_default(self, user=AnonymousUser()):
         from tendenci.apps.entities.models import Entity
-        from tendenci.core.site_settings.utils import get_global_setting
+        from tendenci.apps.site_settings.utils import get_global_setting
         group = self.first()
         if not group:
             entity = Entity.objects.first()
             if not entity:
                 entity = Entity.objects.get_or_create_default(user)
             params = {'name': get_global_setting('sitedisplayname') or 'Tendenci',
+                  'dashboard_url': '',
                   'entity': entity,
                   'type': 'distribution',
                   'email_recipient': get_global_setting('sitecontactemail'),
@@ -36,7 +38,7 @@ class GroupManager(TendenciBaseManager):
                   'status': True,
                   'status_detail': 'active'
                   }
-            if not user.is_anonymous():
+            if not user.is_anonymous:
                 params.update({'creator': user,
                                'creator_username': user.username,
                                'owner': user,
@@ -83,7 +85,7 @@ class OldGroupManager(Manager):
             sqs = sqs.auto_query(sqs.query.clean(query))
             if user:
                 if not is_a_superuser:
-                    if not user.is_anonymous():
+                    if not user.is_anonymous:
                     # if b/w superuser and anon
 
                         # (status+status_detail+(anon OR user)) OR (who_can_view__exact)
@@ -125,7 +127,7 @@ class OldGroupManager(Manager):
                     #sqs = sqs.all()
                     sqs = sqs.filter(status=True)
                 else:
-                    if not user.is_anonymous():
+                    if not user.is_anonymous:
                         # (status+status_detail+anon OR who_can_view__exact)
                         anon_query = Q(**{'allow_anonymous_view':True,})
                         user_query = Q(**{'allow_user_view':True,})
@@ -161,4 +163,3 @@ class OldGroupManager(Manager):
         sqs = sqs.order_by('-create_dt')
 
         return sqs.models(self.model)
-
